Class for storing results from run_methyltfr function.
Details
This class inherits from
SummarizedExperiment, and most methods
for that class should work for objects of this class as well. Additionally,
two accessor functions are defined for extracting bias corrected deviations
(deviations) and deviation Z-scores
(deviationZScores)